searchData={"items":[{"type":"module","title":"OrderedMap","doc":"","ref":"OrderedMap.html"},{"type":"function","title":"OrderedMap.delete/2","doc":"Deletes the entry in `ordered_map` having key `key`.","ref":"OrderedMap.html#delete/2"},{"type":"function","title":"Examples - OrderedMap.delete/2","doc":"iex> ordered_map =\n    ...>   %OrderedMap{\n    ...>     keys: [\"key2\", \"key1\"],\n    ...>     map: %{\"key1\" => 1, \"key2\" => 2},\n    ...>     size: 2,\n    ...>   }\n    iex> OrderedMap.delete(ordered_map, \"key1\")\n    %OrderedMap{\n      keys: [\"key2\"],\n      map: %{\"key2\" => 2},\n      size: 1\n    }\n\n    iex> ordered_map =\n    ...>   %OrderedMap{\n    ...>     keys: [\"key1\"],\n    ...>     map: %{\"key1\" => 1},\n    ...>     size: 1\n    ...>   }\n    iex> OrderedMap.delete(ordered_map, \"key2\")\n    %OrderedMap{\n      keys: [\"key1\"],\n      map: %{\"key1\" => 1},\n      size: 1\n    }\n\n    iex> OrderedMap.delete(OrderedMap.new(), \"key\")\n    %OrderedMap{keys: [], map: %{}, size: 0}","ref":"OrderedMap.html#delete/2-examples"},{"type":"function","title":"OrderedMap.fetch/2","doc":"Fetches the value for a specific `key` in the given\n`ordered_map`.","ref":"OrderedMap.html#fetch/2"},{"type":"function","title":"Examples - OrderedMap.fetch/2","doc":"iex> ordered_map =\n    ...>   %OrderedMap{\n    ...>     keys: [\"key2\", \"key1\"],\n    ...>     map: %{\"key1\" => 1, \"key2\" => 2},\n    ...>     size: 2,\n    ...>   }\n    iex> OrderedMap.fetch(ordered_map, \"key1\")\n    {:ok, 1}\n\n    iex> ordered_map = OrderedMap.new()\n    iex> OrderedMap.fetch(ordered_map, \"key\")\n    :error","ref":"OrderedMap.html#fetch/2-examples"},{"type":"function","title":"OrderedMap.get/3","doc":"Gets the value for a specific `key`.","ref":"OrderedMap.html#get/3"},{"type":"function","title":"Examples - OrderedMap.get/3","doc":"iex> ordered_map =\n    ...>   %OrderedMap{\n    ...>     keys: [\"key2\", \"key1\"],\n    ...>     map: %{\"key1\" => 1, \"key2\" => 2},\n    ...>     size: 2,\n    ...>   }\n    iex> OrderedMap.get(ordered_map, \"key2\")\n    2\n\n    iex> ordered_map =\n    ...>   %OrderedMap{\n    ...>     keys: [\"key1\"],\n    ...>     map: %{\"key1\" => 1},\n    ...>     size: 1,\n    ...>   }\n    iex> OrderedMap.get(ordered_map, \"key2\")\n    nil\n\n    iex> OrderedMap.get(OrderedMap.new(), \"key\")\n    nil\n\n    iex> OrderedMap.get(OrderedMap.new(), \"key\", :default)\n    :default","ref":"OrderedMap.html#get/3-examples"},{"type":"function","title":"OrderedMap.get_and_update/3","doc":"Gets the value from `key` and updates it, all in one pass.","ref":"OrderedMap.html#get_and_update/3"},{"type":"function","title":"Examples - OrderedMap.get_and_update/3","doc":"iex> ordered_map =\n    ...>   %OrderedMap{\n    ...>     keys: [\"key2\", \"key1\"],\n    ...>     map: %{\"key1\" => 1, \"key2\" => 2},\n    ...>     size: 2,\n    ...>   }\n    iex> fun = fn current -> {current, 3} end\n    iex> OrderedMap.get_and_update(ordered_map, \"key1\",fun)\n    { 1,\n      %OrderedMap{\n        keys: [\"key2\", \"key1\"],\n        map: %{\"key1\" => 3, \"key2\" => 2},\n        size: 2,\n      }\n    }","ref":"OrderedMap.html#get_and_update/3-examples"},{"type":"function","title":"OrderedMap.has_key?/2","doc":"Returns whether a given `key` exists in the given\n`ordered_map`.","ref":"OrderedMap.html#has_key?/2"},{"type":"function","title":"Examples - OrderedMap.has_key?/2","doc":"iex> ordered_map =\n    ...>   %OrderedMap{\n    ...>     keys: [\"key2\", \"key1\"],\n    ...>     map: %{\"key1\" => 1, \"key2\" => 2},\n    ...>     size: 2,\n    ...>   }\n    iex> OrderedMap.has_key?(ordered_map, \"key1\")\n    true\n\n    iex> OrderedMap.has_key?(OrderedMap.new(), \"key\")\n    false","ref":"OrderedMap.html#has_key?/2-examples"},{"type":"function","title":"OrderedMap.keys/1","doc":"Returns all keys from `ordered_map`.","ref":"OrderedMap.html#keys/1"},{"type":"function","title":"Examples - OrderedMap.keys/1","doc":"iex> ordered_map =\n    ...>   %OrderedMap{\n    ...>     keys: [\"key2\", \"key1\"],\n    ...>     map: %{\"key1\" => 1, \"key2\" => 2},\n    ...>     size: 2,\n    ...>   }\n    iex> OrderedMap.keys ordered_map\n    [\"key1\", \"key2\"]\n\n    iex> OrderedMap.keys OrderedMap.new()\n    []","ref":"OrderedMap.html#keys/1-examples"},{"type":"function","title":"OrderedMap.new/0","doc":"Returns a new ordered map.","ref":"OrderedMap.html#new/0"},{"type":"function","title":"Examples - OrderedMap.new/0","doc":"iex> OrderedMap.new()\n    %OrderedMap{keys: [], map: %{}, size: 0}","ref":"OrderedMap.html#new/0-examples"},{"type":"function","title":"OrderedMap.pop/2","doc":"Returns and removes the value associated with `key` in\n`ordered_map`.","ref":"OrderedMap.html#pop/2"},{"type":"function","title":"Examples - OrderedMap.pop/2","doc":"iex> ordered_map =\n    ...>   %OrderedMap{\n    ...>     keys: [\"key2\", \"key1\"],\n    ...>     map: %{\"key1\" => 1, \"key2\" => 2},\n    ...>     size: 2,\n    ...>   }\n    iex> OrderedMap.pop(ordered_map, \"key1\")\n    { 1,\n      %OrderedMap{\n        keys: [\"key2\"],\n        map: %{\"key2\" => 2},\n        size: 1,\n      }\n    }","ref":"OrderedMap.html#pop/2-examples"},{"type":"function","title":"OrderedMap.put/3","doc":"Puts the given `value` under `key`.","ref":"OrderedMap.html#put/3"},{"type":"function","title":"Examples - OrderedMap.put/3","doc":"iex> ordered_map = OrderedMap.new()\n    iex> ordered_map =\n    ...>   OrderedMap.put(ordered_map, \"key1\", 1)\n    %OrderedMap{\n      keys: [\"key1\"],\n      map: %{\"key1\" => 1},\n      size: 1,\n    }\n    iex> OrderedMap.put(ordered_map, \"key2\", 2)\n    %OrderedMap{\n      keys: [\"key2\", \"key1\"],\n      map: %{\"key1\" => 1, \"key2\" => 2},\n      size: 2,\n    }\n    iex> OrderedMap.put(ordered_map, \"key2\", 3)\n    %OrderedMap{\n      keys: [\"key2\", \"key1\"],\n      map: %{\"key1\" => 1, \"key2\" => 3},\n      size: 2,\n    }","ref":"OrderedMap.html#put/3-examples"},{"type":"function","title":"OrderedMap.put_new/3","doc":"Puts the given `value` under `key` unless the entry `key`\nalready exists.","ref":"OrderedMap.html#put_new/3"},{"type":"function","title":"Examples - OrderedMap.put_new/3","doc":"iex> ordered_map = OrderedMap.new()\n    iex> ordered_map =\n    ...>   OrderedMap.put_new(ordered_map, \"key1\", 1)\n    %OrderedMap{\n      keys: [\"key1\"],\n      map: %{\"key1\" => 1},\n      size: 1,\n    }\n    iex> OrderedMap.put_new(ordered_map, \"key1\", 2)\n    %OrderedMap{\n      keys: [\"key1\"],\n      map: %{\"key1\" => 1},\n      size: 1,\n    }","ref":"OrderedMap.html#put_new/3-examples"},{"type":"function","title":"OrderedMap.put_new!/3","doc":"Puts the given `value` under `key`. If `key` exists, a\n`RuntimeError` is raised.","ref":"OrderedMap.html#put_new!/3"},{"type":"function","title":"Examples - OrderedMap.put_new!/3","doc":"iex> ordered_map = OrderedMap.new()\n    iex> ordered_map =\n    ...>   OrderedMap.put_new!(ordered_map, \"key1\", 1)\n    %OrderedMap{\n      keys: [\"key1\"],\n      map: %{\"key1\" => 1},\n      size: 1,\n    }\n    iex> OrderedMap.put_new!(ordered_map, \"key1\", 2)\n    ** (RuntimeError) key \"key1\" already exists","ref":"OrderedMap.html#put_new!/3-examples"},{"type":"function","title":"OrderedMap.values/1","doc":"Returns all values from `ordered_map`.","ref":"OrderedMap.html#values/1"},{"type":"function","title":"Examples - OrderedMap.values/1","doc":"iex> ordered_map =\n    ...>   %OrderedMap{\n    ...>     keys: [\"key2\", \"key1\"],\n    ...>     map: %{\"key1\" => 1, \"key2\" => 2},\n    ...>     size: 2,\n    ...>   }\n    iex> OrderedMap.values ordered_map\n    [1, 2]\n\n    iex> OrderedMap.values OrderedMap.new()\n    []","ref":"OrderedMap.html#values/1-examples"},{"type":"type","title":"OrderedMap.key/0","doc":"","ref":"OrderedMap.html#t:key/0"},{"type":"type","title":"OrderedMap.t/0","doc":"","ref":"OrderedMap.html#t:t/0"},{"type":"extras","title":"OrderedMap","doc":"# OrderedMap\n\n[![Build Status](https://gitlab.com/jonnystorm/ordered-map-elixir/badges/master/pipeline.svg)](https://gitlab.com/jonnystorm/ordered-map-elixir/commits/master)\n\n> An order-preserving map implementation for Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - OrderedMap","doc":"Add `ordered_map` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:ordered_map, \"~> 0.0.8\"}]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Docs - OrderedMap","doc":"Read [here](https://hexdocs.pm/ordered_map/OrderedMap.html).","ref":"readme.html#docs"},{"type":"extras","title":"License - OrderedMap","doc":"[MPL-2.0](./COPYING.MPL)","ref":"readme.html#license"}],"content_type":"text/markdown"}